---
layout: template
title: Development
permalink: /development/
link_group: development
---
# Development

These sections cover the basics on how you develop with `pyatv`.
So if you are a developer and want to create some software that
controls an Apple TV, you are in the right place.

If you instead want develop `pyatv` itself, there are details for
that over at the GitHub wiki. Click
[here](https://github.com/postlund/pyatv/wiki) to go there.
